@@ -31,6 +31,7 @@ from tdw.FBOutput import AudioSources as Audi
 from tdw.FBOutput import Raycast as Ray
 from tdw.FBOutput import Overlap as Over
 from tdw.FBOutput import NavMeshPath as Path
+from tdw.FBOutput import Keyboard as Key
 import numpy as np
 from typing import Tuple, Optional
 
@@ -216,7 +217,8 @@ class Images(OutputData):
                   PassMask.PassMask._depth: "_depth",
                   PassMask.PassMask._normals: "_normals",
                   PassMask.PassMask._flow: "_flow",
-                  PassMask.PassMask._depth_simple: "_depth_simple"
+                  PassMask.PassMask._depth_simple: "_depth_simple",
+                  PassMask.PassMask._albedo: "_albedo"
                   }
 
     def get_data(self) -> Imags.Images:
@@ -795,3 +797,26 @@ class NavMeshPath(OutputData):
 
     def get_id(self) -> int:
         return self.data.Id()
+
+
+class Keyboard(OutputData):
+    def get_data(self) -> Key.Keyboard:
+        return Key.Keyboard.GetRootAsKeyboard(self.bytes, 0)
+
+    def get_num_pressed(self) -> int:
+        return self.data.PressedLength()
+
+    def get_pressed(self, index: int) -> str:
+        return self.data.Pressed(index).decode('utf-8')
+
+    def get_num_held(self) -> int:
+        return self.data.HeldLength()
+
+    def get_held(self, index: int) -> str:
+        return self.data.Held(index).decode('utf-8')
+
+    def get_num_released(self) -> int:
+        return self.data.ReleasedLength()
+
+    def get_released(self, index: int) -> str:
+        return self.data.Released(index).decode('utf-8')
